@@ -65,7 +65,7 @@ impl Api {
                 let songtag_vec = to_song_info(&result).ok_or_else(|| anyhow!("Search Error"))?;
                 let songtag_string = serde_json::to_string(&songtag_vec)?;
                 Ok(songtag_string)
-            },
+            }
             _ => Err(anyhow!("None Error")),
         }
     }
@@ -94,9 +94,8 @@ impl Api {
             .call()?
             .into_string()?;
 
-        let mut url = String::from("https:");
         let pic_url = to_pic_url(&result).ok_or_else(|| anyhow!("Pic url error"))?;
-        url.push_str(&pic_url);
+        let url = format!("https:{}", pic_url);
 
         let result = self.client.get(&url).call()?;
 
