@@ -2,6 +2,7 @@
 //!
 //! demo example components
 
+mod general_search;
 /**
  * MIT License
  *
@@ -29,20 +30,20 @@
 // mod clock;
 // mod counter;
 mod label;
-mod library_search;
 mod lyric;
 mod music_library;
 mod playlist;
 mod popups;
 mod progress;
+mod table_playlist;
 mod tageditor;
 mod youtube_search;
 
 // -- export
 // pub use clock::Clock;
 // pub use counter::{Digit, Letter};
+pub use general_search::{GSInputPopup, GSTablePopup, Source};
 pub use label::Label;
-pub use library_search::{LSInputPopup, LSTablePopup};
 pub use lyric::Lyric;
 pub use music_library::MusicLibrary;
 pub use playlist::Playlist;
@@ -51,6 +52,7 @@ pub use popups::{
     QuitPopup,
 };
 pub use progress::Progress;
+pub use table_playlist::Table;
 pub use youtube_search::{YSInputPopup, YSTablePopup};
 //Tag Edotor Controls
 pub use tageditor::{
@@ -59,6 +61,10 @@ pub use tageditor::{
 };
 
 use crate::ui::{Id, Loop, Model, Msg, Status};
+use anyhow::{anyhow, bail, Result};
+use std::io::Write;
+#[cfg(feature = "cover")]
+use std::path::PathBuf;
 use tui_realm_stdlib::Phantom;
 use tuirealm::props::{Alignment, Borders, Color, Style};
 use tuirealm::tui::layout::{Constraint, Direction, Layout, Rect};
@@ -69,6 +75,14 @@ use tuirealm::{
 };
 use tuirealm::{Sub, SubClause, SubEventClause};
 
+#[allow(dead_code)]
+pub struct Xywh {
+    pub x: u16,
+    pub y: u16,
+    pub width: u32,
+    pub height: u32,
+}
+
 #[derive(Default, MockComponent)]
 pub struct GlobalListener {
     component: Phantom,
@@ -317,6 +331,88 @@ impl Model {
         self.player.seek(offset).ok();
         self.progress_update();
     }
+    // update picture of album
+    #[allow(clippy::cast_possible_truncation, clippy::cast_possible_wrap)]
+    pub fn update_photo(&mut self) -> Result<()> {
+        self.clear_photo()?;
+
+        let song = match &self.current_song {
+            Some(song) => song,
+            None => bail!("no current song"),
+        };
+
+        // just show the first photo
+        if let Some(picture) = song.picture() {
+            if let Ok(image) = image::load_from_memory(&picture.data) {
+                let (term_width, term_height) = viuer::terminal_size();
+                // Set desired image dimensions
+                let (orig_width, orig_height) = image::GenericImageView::dimensions(&image);
+                // let ratio = f64::from(orig_height) / f64::from(orig_width);
+                let width = 20_u16;
+                let height = (width * orig_height as u16).checked_div(orig_width as u16);
+                if let Some(height) = height {
+                    let xywh = Xywh {
+                        x: term_width - width - 1,
+                        y: (term_height - height / 2 - 8) - 1,
+                        width: u32::from(width),
+                        height: u32::from(height),
+                    };
+                    // if terminal is not kitty or item, show photo with ueberzug
+                    // if (viuer::KittySupport::Local == viuer::get_kitty_support())
+                    //     || viuer::is_iterm_supported()
+                    if self.viuer_supported {
+                        let config = viuer::Config {
+                            transparent: true,
+                            absolute_offset: true,
+                            x: xywh.x,
+                            y: xywh.y as i16,
+                            // x: term_width / 3 - width - 1,
+                            // y: (term_height - height / 2) as i16 - 2,
+                            width: Some(xywh.width),
+                            height: None,
+                            ..viuer::Config::default()
+                        };
+                        viuer::print(&image, &config)
+                            .map_err(|e| anyhow!("viuer print error: {}", e))?;
+
+                        return Ok(());
+                    };
+                    #[cfg(feature = "cover")]
+                    {
+                        let mut cache_file =
+                            dirs_next::cache_dir().unwrap_or_else(|| PathBuf::from("/tmp"));
+                        cache_file.push("termusic_cover.jpg");
+                        image.save(cache_file.clone())?;
+                        // image.save(Path::new("/tmp/termusic_cover.jpg"))?;
+                        if let Some(file) = cache_file.as_path().to_str() {
+                            self.ueberzug_instance.draw_cover_ueberzug(file, &xywh);
+                        }
+                    }
+                }
+            }
+        }
+        Ok(())
+    }
+
+    pub fn clear_photo(&mut self) -> Result<()> {
+        // clear all previous image
+        // if (viuer::KittySupport::Local == viuer::get_kitty_support()) || viuer::is_iterm_supported()
+        // {
+
+        if self.viuer_supported {
+            self.clear_image_viuer()
+                .map_err(|e| anyhow!("Clear album photo error: {}", e))?;
+            return Ok(());
+        }
+        #[cfg(feature = "cover")]
+        self.ueberzug_instance.clear_cover_ueberzug();
+        Ok(())
+    }
+    fn clear_image_viuer(&mut self) -> Result<()> {
+        write!(self.terminal.raw_mut().backend_mut(), "\x1b_Ga=d\x1b\\")?;
+        self.terminal.raw_mut().backend_mut().flush()?;
+        Ok(())
+    }
 }
 ///
 /// Get block
