@@ -2,9 +2,10 @@
 use crate::{
     config::get_app_config_path,
     song::Song,
-    ui::{Id, Model, Msg},
+    ui::{components::table_playlist::TABLE_INITIAL_INDEX, Id, Model, Msg},
 };
 
+use super::Table;
 use crate::ui::Loop;
 use anyhow::Result;
 use humantime::format_duration;
@@ -17,14 +18,15 @@ use std::path::Path;
 use std::str::FromStr;
 use std::thread;
 use std::time::Duration;
-use tui_realm_stdlib::Table;
 use tuirealm::command::{Cmd, CmdResult, Direction, Position};
-use tuirealm::props::{Alignment, BorderType, Borders, Color, TableBuilder, TextSpan};
+use tuirealm::props::{Alignment, BorderType, TableBuilder, TextSpan};
 use tuirealm::{
     event::{Key, KeyEvent, KeyModifiers},
-    Component, Event, MockComponent, NoUserEvent, State, StateValue,
+    AttrValue, Attribute, Component, Event, MockComponent, NoUserEvent, State, StateValue,
 };
 
+use tuirealm::props::{Borders, Color};
+
 #[derive(MockComponent)]
 pub struct Playlist {
     component: Table,
@@ -129,7 +131,13 @@ impl Component<Msg, NoUserEvent> for Playlist {
                 code: Key::Char('a'),
                 ..
             }) => return Some(Msg::PlaylistAddFront),
-
+            Event::Keyboard(KeyEvent {
+                code: Key::Char('/'),
+                ..
+            }) => return Some(Msg::GeneralSearchPopupShowPlaylist),
+            // Event::User(UserEvent::GotoTableIndex(index)) => {
+            //     self.perform(Cmd::GoTo(Position::At(index)))
+            // }
             _ => CmdResult::None,
         };
         // match cmd_result {
@@ -143,10 +151,14 @@ impl Component<Msg, NoUserEvent> for Playlist {
 }
 
 impl Model {
-    pub fn playlist_add(&mut self, current_node: &str) -> Result<()> {
+    pub fn playlist_add_item(
+        &mut self,
+        current_node: &str,
+        add_playlist_front: bool,
+    ) -> Result<()> {
         match Song::from_str(current_node) {
             Ok(item) => {
-                if self.config.add_playlist_front {
+                if add_playlist_front {
                     self.playlist_items.push_front(item);
                 } else {
                     self.playlist_items.push_back(item);
@@ -157,6 +169,23 @@ impl Model {
         }
         Ok(())
     }
+    pub fn playlist_add(&mut self, current_node: &str) {
+        let p: &Path = Path::new(&current_node);
+        if p.exists() {
+            if p.is_dir() {
+                let new_items = Self::library_dir_children(p);
+                for s in &new_items {
+                    if let Err(e) = self.playlist_add_item(s, false) {
+                        self.mount_error_popup(format!("Add playlist error: {}", e).as_str());
+                    }
+                }
+            } else if let Err(e) =
+                self.playlist_add_item(current_node, self.config.add_playlist_front)
+            {
+                self.mount_error_popup(format!("Add Playlist error: {}", e).as_str());
+            }
+        }
+    }
 
     pub fn playlist_sync(&mut self) {
         let mut table: TableBuilder = TableBuilder::default();
@@ -285,9 +314,13 @@ impl Model {
             duration += v.duration();
         }
         let add_queue = if self.config.add_playlist_front {
-            "front"
+            "\u{fb22}"
+            // "ﬢ"
+            // "front"
         } else {
-            "back"
+            "\u{fb20}"
+            // "ﬠ"
+            // "back"
         };
 
         let title = format!(
@@ -335,4 +368,41 @@ impl Model {
             self.player_next();
         }
     }
+    pub fn playlist_update_search(&mut self, input: &str) {
+        let mut table: TableBuilder = TableBuilder::default();
+        let mut idx = 0;
+        let search = format!("*{}*", input.to_lowercase());
+        for record in &self.playlist_items {
+            // for record in all_items.into_iter().filter_map(std::result::Result::ok) {
+            if let Some(file_name) = record.name() {
+                if wildmatch::WildMatch::new(&search).matches(&file_name.to_string().to_lowercase())
+                {
+                    if idx > 0 {
+                        table.add_row();
+                    }
+                    idx += 1;
+                    table
+                        .add_col(TextSpan::new(idx.to_string()))
+                        .add_col(TextSpan::new(file_name.to_string()));
+                }
+            }
+        }
+        let table = table.build();
+
+        self.general_search_update_library(table);
+    }
+
+    #[allow(clippy::cast_possible_wrap)]
+    pub fn playlist_locate(&mut self, index: Option<usize>) {
+        if let Some(i) = index {
+            assert!(self
+                .app
+                .attr(
+                    &Id::Playlist,
+                    Attribute::Custom(TABLE_INITIAL_INDEX),
+                    AttrValue::Number(i as isize),
+                )
+                .is_ok());
+        }
+    }
 }
