@@ -25,7 +25,6 @@
  * SOFTWARE.
  */
 use crate::ui::{model::UpdateComponents, Id, Model, Msg, StatusLine};
-use std::path::Path;
 use std::thread::{self, sleep};
 use std::time::Duration;
 use tuirealm::props::{AttrValue, Attribute, Color};
@@ -94,18 +93,21 @@ impl Update<Msg> for Model {
                     }
                     None
                 }
-                Msg::LibrarySearchPopupShow
-                | Msg::LibrarySearchPopupUpdate(_)
-                | Msg::LibrarySearchPopupCloseCancel
-                | Msg::LibrarySearchInputBlur
-                | Msg::LibrarySearchTableBlur
-                | Msg::LibrarySearchPopupCloseAddPlaylist
-                | Msg::LibrarySearchPopupCloseOkLocate => {
-                    self.update_library_search(&msg);
+                Msg::GeneralSearchPopupShowLibrary
+                | Msg::GeneralSearchPopupShowPlaylist
+                | Msg::GeneralSearchPopupUpdateLibrary(_)
+                | Msg::GeneralSearchPopupUpdatePlaylist(_)
+                | Msg::GeneralSearchPopupCloseCancel
+                | Msg::GeneralSearchInputBlur
+                | Msg::GeneralSearchTableBlur
+                | Msg::GeneralSearchPopupCloseLibraryAddPlaylist
+                | Msg::GeneralSearchPopupCloseOkLibraryLocate
+                | Msg::GeneralSearchPopupCloseOkPlaylistLocate
+                | Msg::GeneralSearchPopupClosePlaylistPlaySelected => {
+                    self.update_general_search(&msg);
                     None
                 }
                 Msg::PlaylistAdd(_)
-                | Msg::PlaylistAddSongs(_)
                 | Msg::PlaylistDelete(_)
                 | Msg::PlaylistDeleteAll
                 | Msg::PlaylistShuffle
@@ -255,40 +257,61 @@ impl Model {
             _ => {}
         }
     }
-    pub fn update_library_search(&mut self, msg: &Msg) {
+    pub fn update_general_search(&mut self, msg: &Msg) {
         match msg {
-            Msg::LibrarySearchPopupShow => {
+            Msg::GeneralSearchPopupShowLibrary => {
                 self.mount_search_library();
                 self.library_update_search("*");
             }
-            Msg::LibrarySearchPopupUpdate(input) => {
+            Msg::GeneralSearchPopupShowPlaylist => {
+                self.mount_search_playlist();
+                self.playlist_update_search("*");
+            }
+
+            Msg::GeneralSearchPopupUpdateLibrary(input) => {
                 self.library_update_search(input);
             }
-            Msg::LibrarySearchPopupCloseCancel => {
-                self.app.umount(&Id::LibrarySearchInput).ok();
-                self.app.umount(&Id::LibrarySearchTable).ok();
+            Msg::GeneralSearchPopupUpdatePlaylist(input) => {
+                self.playlist_update_search(input);
+            }
+
+            Msg::GeneralSearchPopupCloseCancel => {
+                self.app.umount(&Id::GeneralSearchInput).ok();
+                self.app.umount(&Id::GeneralSearchTable).ok();
                 self.app.unlock_subs();
             }
-            Msg::LibrarySearchInputBlur => {
-                if self.app.mounted(&Id::LibrarySearchTable) {
-                    self.app.active(&Id::LibrarySearchTable).ok();
+            Msg::GeneralSearchInputBlur => {
+                if self.app.mounted(&Id::GeneralSearchTable) {
+                    self.app.active(&Id::GeneralSearchTable).ok();
                 }
             }
-            Msg::LibrarySearchTableBlur => {
-                if self.app.mounted(&Id::LibrarySearchInput) {
-                    self.app.active(&Id::LibrarySearchInput).ok();
+            Msg::GeneralSearchTableBlur => {
+                if self.app.mounted(&Id::GeneralSearchInput) {
+                    self.app.active(&Id::GeneralSearchInput).ok();
                 }
             }
-            Msg::LibrarySearchPopupCloseAddPlaylist => {
-                self.library_add_playlist_after_search();
-                self.app.umount(&Id::LibrarySearchInput).ok();
-                self.app.umount(&Id::LibrarySearchTable).ok();
+            Msg::GeneralSearchPopupCloseLibraryAddPlaylist => {
+                self.general_search_after_library_add_playlist();
+                self.app.umount(&Id::GeneralSearchInput).ok();
+                self.app.umount(&Id::GeneralSearchTable).ok();
                 self.app.unlock_subs();
             }
-            Msg::LibrarySearchPopupCloseOkLocate => {
-                self.library_select_after_search();
-                self.app.umount(&Id::LibrarySearchInput).ok();
-                self.app.umount(&Id::LibrarySearchTable).ok();
+            Msg::GeneralSearchPopupCloseOkLibraryLocate => {
+                self.general_search_after_select_library();
+                self.app.umount(&Id::GeneralSearchInput).ok();
+                self.app.umount(&Id::GeneralSearchTable).ok();
+                self.app.unlock_subs();
+            }
+            Msg::GeneralSearchPopupClosePlaylistPlaySelected => {
+                self.general_search_after_playlist_play_selected();
+                self.app.umount(&Id::GeneralSearchInput).ok();
+                self.app.umount(&Id::GeneralSearchTable).ok();
+                self.app.unlock_subs();
+            }
+            Msg::GeneralSearchPopupCloseOkPlaylistLocate => {
+                self.general_search_after_select_playlist();
+                self.app.umount(&Id::GeneralSearchInput).ok();
+                self.app.umount(&Id::GeneralSearchTable).ok();
                 self.app.unlock_subs();
             }
             _ => {}
@@ -327,20 +350,7 @@ impl Model {
     pub fn update_playlist(&mut self, msg: Msg) {
         match msg {
             Msg::PlaylistAdd(current_node) => {
-                if let Err(e) = self.playlist_add(&current_node) {
-                    self.mount_error_popup(format!("Add Playlist error: {}", e).as_str());
-                }
-            }
-            Msg::PlaylistAddSongs(current_node) => {
-                let p: &Path = Path::new(&current_node);
-                if p.exists() {
-                    let new_items = Self::library_dir_children(p);
-                    for s in &new_items {
-                        if let Err(e) = self.playlist_add(s) {
-                            self.mount_error_popup(format!("Add playlist error: {}", e).as_str());
-                        }
-                    }
-                }
+                self.playlist_add(&current_node);
             }
             Msg::PlaylistDelete(index) => {
                 self.playlist_delete_item(index);
